@@ -9,6 +9,8 @@
 //! Two queues are considered equal if iterating over them with `iter()` would yield the same
 //! sequence of elements.
 //!
+//! Enable the `serde_support` feature for [Serde](https://serde.rs/) support.
+//!
 //! # Examples
 //!
 //! ```
@@ -30,7 +32,7 @@
 //! ```
 
 #![cfg_attr(has_extern_crate_alloc, no_std)]
-#![doc(html_root_url = "https://docs.rs/circular-queue/0.2.4")]
+#![doc(html_root_url = "https://docs.rs/circular-queue/0.2.5")]
 
 #[cfg(has_extern_crate_alloc)]
 extern crate alloc;
@@ -47,6 +49,9 @@ use std::iter::{Chain, Rev};
 #[cfg(not(has_extern_crate_alloc))]
 use std::slice::{Iter as SliceIter, IterMut as SliceIterMut};
 
+#[cfg(feature = "serde_support")]
+mod serde_support;
+
 /// A circular buffer-like queue.
 #[derive(Clone, Debug)]
 pub struct CircularQueue<T> {
